check_packages: check_packages

View source: R/geoflow_utils.R

check_packagesR Documentation

check_packages

Description

check_packages checks availability of a list of R packages in R. This function is essentially used internally by geoflow in assocation to geoflow_software and geoflow_action that would need specific packages to be imported in R.

Usage

check_packages(pkgs)

Arguments

pkgs

a vector of package names

Author(s)

Emmanuel Blondel, emmanuel.blondel1@gmail.com


geoflow documentation built on Dec. 12, 2025, 5:08 p.m.