View source: R/debugWorkflow.R
| debugWorkflow | R Documentation |
debugWorkflow allows to initiate a workflow job for
developers to work / debug on workflow actions.
debugWorkflow(file, dir, entityIndex, copyData, runSoftwareActions, runLocalActions)
file |
configuration file |
dir |
directory where to debug/execute the workflow |
entityIndex |
index of the entity within the list of loaded entities. Default is 1 |
copyData |
whether data should be downloaded/copied to job data directory.
Default is |
runSoftwareActions |
whether software actions should be run. Default is |
runLocalActions |
whether entity data local actions (if any) should be run.
Default is |
a named list including the workflow config, the selected entity,
the eventual options associated to the entity, and the output entity dir path
of the selected entity.
Emmanuel Blondel, emmanuel.blondel1@gmail.com
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.