executeWorkflow: executeWorkflow

View source: R/executeWorkflow.R

executeWorkflowR Documentation

executeWorkflow

Description

executeWorkflow allows to execute a workflow

Usage

executeWorkflow(file, dir, outdir, queue, 
                       on_initWorkflowJob, on_initWorkflow, on_closeWorkflow, 
                       monitor, session)

Arguments

file

a JSON geoflow configuration file

dir

a directory used to execute the workflow. This is the working directory, ie where local resources (data, metadata), should be located.

outdir

a directory where the geoflow will write the job outputs.

queue

an ipc queue to use geoflow in geoflow-shiny

on_initWorkflowJob

a function to trigger once initWorkflowJob is executed

on_initWorkflow

a function to trigger once initWorkflow is executed

on_closeWorkflow

a function to trigger once closeWorkflow is executed

monitor

a monitor function to increase progress bar

session

a shiny session object (optional) to run geoflow in a shiny context

Value

the path of the job directory

Author(s)

Emmanuel Blondel, emmanuel.blondel1@gmail.com


geoflow documentation built on Sept. 5, 2026, 5:08 p.m.