| geoflowLogger | R Documentation |
geoflowLogger
R6Class object.
Object of R6Class for modelling a simple logger
verboseverbose
debugdebug
geoflowLogger$separator()Util to separate chunks of logs of different natures
geoflowLogger$separator(char)
charA character to be used, eg '='
geoflowLogger$INFO()Prints an INFO logger message
geoflowLogger$INFO(txt, ...)
txtlogger message
...values to be passed into txt. See sprintf
geoflowLogger$WARN()Prints an WARN logger message
geoflowLogger$WARN(txt, ...)
txtlogger message
...values to be passed into txt. See sprintf
geoflowLogger$ERROR()Prints an ERROR logger message
geoflowLogger$ERROR(txt, ...)
txtlogger message
...values to be passed into txt. See sprintf
geoflowLogger$DEBUG()Prints an DEBUG logger message
geoflowLogger$DEBUG(txt, ...)
txtlogger message
...values to be passed into txt. See sprintf
geoflowLogger$new()Initializes an object of class geoflowLogger
geoflowLogger$new(verbose = TRUE, debug = FALSE)
verboseTRUE if the logger is enabled, FALSE otherwise. Default is TRUE
debugTRUE if the debugger is enabled, FALSE otherwise. Default is FALSE
geoflowLogger$clone()The objects of this class are cloneable with this method.
geoflowLogger$clone(deep = FALSE)
deepWhether to make a deep clone.
Logger class used internally by geoflow
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.