| geoflow_contact | R Documentation |
This class models a contact to be executed by geoflow
R6Class object.
geoflow_contact
Object of R6Class for modelling a contact
idcontact identifier
firstNamecontact first name
lastNamecontact lastname
organizationNamecontact organization
positionNamecontact position
rolecontact role
voicecontact phone number
facsimilecontact facsimile
emailcontact email
websiteUrlcontact website URL
websiteNamecontact website name
postalAddresscontact postal address
postalCodecontact postal code
citycontact city
countrycontact country
identifierscontact identifiers
geoflow_contact$new()Initializes a geoflow_contact object
geoflow_contact$new()
geoflow_contact$setShinyEditorMode()Set mode for geoflow-shiny
geoflow_contact$setShinyEditorMode(mode = c("creation", "edition"))
modemode
geoflow_contact$getShinyEditorMode()Get mode for geoflow-shiny
geoflow_contact$getShinyEditorMode()
the shiny editor mode
geoflow_contact$getAllowedKeyValuesFor()Retrieves keys allowed for a given tabular field name. eg. "Identifier"
geoflow_contact$getAllowedKeyValuesFor(field)
fieldfield name
the list of valid keys for the field considered
geoflow_contact$setIdentifier()Sets an identifier by means of key
geoflow_contact$setIdentifier(key = "id", id)
keyan identifier key. Default is "id"
idthe identifier
geoflow_contact$setId()Sets an "id" identifier
geoflow_contact$setId(id)
idthe identifier
geoflow_contact$setFirstName()Sets contact first name
geoflow_contact$setFirstName(firstName)
firstNamecontact first name
geoflow_contact$setLastName()Sets contact last name
geoflow_contact$setLastName(lastName)
lastNamecontact last name
geoflow_contact$setOrganizationName()Sets contact organization name
geoflow_contact$setOrganizationName(organizationName)
organizationNamecontact organization name
geoflow_contact$setPositionName()Sets contact position name
geoflow_contact$setPositionName(positionName)
positionNamecontact position name
geoflow_contact$setRole()Sets contact role
geoflow_contact$setRole(role)
rolethe contact role
geoflow_contact$setVoice()Sets contact voice (phone number)
geoflow_contact$setVoice(voice)
voicecontact voice (phone number)
geoflow_contact$setFacsimile()Sets contact facsimile
geoflow_contact$setFacsimile(facsimile)
facsimilecontact facsimile
geoflow_contact$setEmail()Sets contact email
geoflow_contact$setEmail(email)
emailcontact email
geoflow_contact$setWebsiteUrl()Sets contact website URL
geoflow_contact$setWebsiteUrl(websiteUrl)
websiteUrlcontact website URL
geoflow_contact$setWebsiteName()Sets contact website name
geoflow_contact$setWebsiteName(websiteName)
websiteNamecontact website name
geoflow_contact$setPostalAddress()Sets the contact postal address
geoflow_contact$setPostalAddress(postalAddress)
postalAddresscontact postal address
geoflow_contact$setPostalCode()Sets the contact postal code
geoflow_contact$setPostalCode(postalCode)
postalCodecontact postalCode
geoflow_contact$setCity()Sets the contact city
geoflow_contact$setCity(city)
citycontact city
geoflow_contact$setCountry()Sets the contact country
geoflow_contact$setCountry(country)
countrycontact country
geoflow_contact$asDataFrame()Methods to export the geoflow_contact as data.frame using key-based syntax.
geoflow_contact$asDataFrame(line_separator = NULL)
line_separatora line separator. By default, the default line separator will be used.
an object of class data.frame giving the entities using key-based syntax
geoflow_contact$clone()The objects of this class are cloneable with this method.
geoflow_contact$clone(deep = FALSE)
deepWhether to make a deep clone.
Emmanuel Blondel <emmanuel.blondel1@gmail.com>
## Not run:
contact <- geoflow_contact$new()
contact$setId("john.doe@nowhere.org")
contact$setFirstName("John")
contact$setLastName("Doe")
contact$setOrganizationName("Nowhere")
contact$setPositionName("Wizard")
contact$setRole("Manager")
contact$setVoice("+9999000000000")
contact$setFacsimile("+9999000000001")
contact$setEmail("john.doe@nowhere.org")
contact$setWebsiteUrl("www.nowhere.org")
contact$setWebsiteName("Nowhere Inc.")
contact$setPostalAddress("Nowhere street")
contact$setPostalCode("Nowhere code")
contact$setCity("Nowhere city")
contact$setCountry("Nowhere country")
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.