geoflow_dictionary: Geoflow dictionary class

geoflow_dictionaryR Documentation

Geoflow dictionary class

Description

This class models a dictionary to be executed by geoflow

Format

R6Class object.

Details

geoflow_dictionary

Value

Object of R6Class for modelling a dictionary

Public fields

source

dictionary source, object of class data.frame

featuretypes

list of objects of class geoflow_featuretype

registers

list of objects of class geoflow_register

Methods

Public methods


Method new()

Initializes a geoflow_dictionary object

Usage
geoflow_dictionary$new()

Method setSource()

Sets dictionnary source

Usage
geoflow_dictionary$setSource(source)
Arguments
source

object of class data.frame


Method getFeatureTypes()

Get the list of geoflow_featuretype defined in the dictionary

Usage
geoflow_dictionary$getFeatureTypes()
Returns

a list of geoflow_featuretype


Method getFeatureTypeById()

Get an object of class geoflow_featuretype given an ID

Usage
geoflow_dictionary$getFeatureTypeById(id)
Arguments
id

id

Returns

an object of class geoflow_featuretype, otherwise NULL


Method addFeatureType()

Adds a feature type to the dictionnary

Usage
geoflow_dictionary$addFeatureType(ft)
Arguments
ft

object of class geoflow_featuretype


Method getRegisters()

Get the list of registers associated with the dictionnary

Usage
geoflow_dictionary$getRegisters()
Returns

a list of geoflow_register objects


Method getRegisterById()

Get register by ID

Usage
geoflow_dictionary$getRegisterById(id)
Arguments
id

id

Returns

an object of class geoflow_register, otherwise NULL


Method addRegister()

Adds a register to the dictionnary

Usage
geoflow_dictionary$addRegister(register)
Arguments
register

object of class geoflow_register


Method clone()

The objects of this class are cloneable with this method.

Usage
geoflow_dictionary$clone(deep = FALSE)
Arguments
deep

Whether to make a deep clone.

Author(s)

Emmanuel Blondel <emmanuel.blondel1@gmail.com>


geoflow documentation built on Dec. 12, 2025, 5:08 p.m.