geoflow_register: Geoflow register class

geoflow_registerR Documentation

Geoflow register class

Description

This class models a register to be used by geoflow

Format

R6Class object.

Details

geoflow_register

Value

Object of R6Class for modelling a register

Public fields

id

register id

def

register def

fun

register function

data

register data

Methods

Public methods


Method new()

Initializes an object of class geoflow_register

Usage
geoflow_register$new(id, def, fun)
Arguments
id

id

def

def

fun

fun


Method fetch()

Fetchs the register data using the register function

Usage
geoflow_register$fetch(config = NULL)
Arguments
config

a geoflow config object


Method check()

Checks the register data structure. The structure of the data.frame returned by the register function should be of 4 columns including "code", "uri", "label", "definition". In case the data structure is not valid, the function throws an error.

Usage
geoflow_register$check(data)
Arguments
data

a register data structure


Method clone()

The objects of this class are cloneable with this method.

Usage
geoflow_register$clone(deep = FALSE)
Arguments
deep

Whether to make a deep clone.

Author(s)

Emmanuel Blondel <emmanuel.blondel1@gmail.com>

Examples

## Not run: 
  register <- geoflow_register$new(
   id = "some-id",
   def = "definition",
   fun = function(){}
  )

## End(Not run)


geoflow documentation built on Dec. 12, 2025, 5:08 p.m.