geoflow_validator: geoflow_validator

geoflow_validatorR Documentation

geoflow_validator

Description

geoflow_validator

Public fields

source

object of class data.frame handling metadata objects to validate

Methods

Public methods


geoflow_validator$new()

Initializes a table validator for a given metadata model

Usage
geoflow_validator$new(model, valid_columns, source)
Arguments
model

the data model name, eg. "entity", "contact"

valid_columns

a vector of valid columns for the data model

source

an object of class data.frame handling the contacts


geoflow_validator$validate_structure()

Validates a source table against a data model structure

Usage
geoflow_validator$validate_structure()
Returns

TRUE if valid, FALSE otherwise.


geoflow_validator$validate_content()

Validates a source table using syntactic and content validation rules

Usage
geoflow_validator$validate_content(raw = FALSE)
Arguments
raw

indicates whether to return a list of geoflow_validator_cell objects or a data.frame

debug

debug validation

Returns

a list of geoflow_validator_cell objects, or data.frame


geoflow_validator$clone()

The objects of this class are cloneable with this method.

Usage
geoflow_validator$clone(deep = FALSE)
Arguments
deep

Whether to make a deep clone.


geoflow documentation built on Sept. 5, 2026, 5:08 p.m.