geoflow_validator_cell: geoflow_validator_cell

geoflow_validator_cellR Documentation

geoflow_validator_cell

Description

geoflow_validator_cell

Public fields

i

row index (internal index to be used for graphical geoflow validation handlers)

j

col index (internal index to be used for graphical geoflow validation handlers)

Methods

Public methods


geoflow_validator_cell$new()

Initializes a geoflow_validator_cell

Usage
geoflow_validator_cell$new(
  na_authorized,
  use_key_syntax,
  key_required,
  valid_keys,
  default_key,
  error_if_invalid_key,
  exclude_http_keys,
  multiple,
  i,
  j,
  str
)
Arguments
na_authorized

if validator cell authorizes NAs or empty strings. Default is FALSE

use_key_syntax

if validator cell uses key-based syntax. Default is TRUE

key_required

if validator cell has a key required. Default is TRUE

valid_keys

valid keys for the validator cell. Default is an empty list

default_key

default_key to use if key is omitted. Default is NULL

error_if_invalid_key

raise an error if key is invalid. Default is TRUE

exclude_http_keys

if 'http' keys have to be excluded from validation checks. Default is TRUE

multiple

if cell may contain multiple values. Deprecated

i

row index (internal index to be used for graphical geoflow validation handlers)

j

col index (internal index to be used for graphical geoflow validation handlers)

str

character string to validate


geoflow_validator_cell$isNaAuthorized()

Indicates if the validator cell authorizes NAs and empty strings

Usage
geoflow_validator_cell$isNaAuthorized()
Returns

TRUE if authorizes NAs and empty strings, FALSE otherwise


geoflow_validator_cell$isKeySynthaxUser()

Indicates if the validator cell makes use of key-based syntax

Usage
geoflow_validator_cell$isKeySynthaxUser()
Returns

TRUE if using key-based syntax, FALSE otherwise


geoflow_validator_cell$isKeyRequired()

Indicates if a key is required for the validator cell

Usage
geoflow_validator_cell$isKeyRequired()
Returns

TRUE if requires a key, FALSE otherwise


geoflow_validator_cell$getValidKeys()

Gives the list of valid keys for the validator cell

Usage
geoflow_validator_cell$getValidKeys()
Returns

the list of valid keys


geoflow_validator_cell$isErrorIfInvalidKey()

Indicates if a report error will be given in case of invalid key

Usage
geoflow_validator_cell$isErrorIfInvalidKey()
Returns

TRUE if a report error will be given in case of invalid key, FALSE otherwise


geoflow_validator_cell$getDefaultKey()

Gets the default key

Usage
geoflow_validator_cell$getDefaultKey()
Returns

the default key


geoflow_validator_cell$isExcludeHttpKeys()

Indicates if 'http' keys are excluded from the validation

Usage
geoflow_validator_cell$isExcludeHttpKeys()
Returns

TRUE if 'http' keys are excluded from the validation, FALSE otherwise


geoflow_validator_cell$isMultiple()

indicates if multiple key-based components can be used within a same cell

Usage
geoflow_validator_cell$isMultiple()
Returns

TRUE if supporting multiple key-based components by cell, FALSE otherwise


geoflow_validator_cell$validate()

Proceeds with syntactic validation for the cell considered

Usage
geoflow_validator_cell$validate()
Returns

an object of class data.frame including possible errors/warnings


geoflow_validator_cell$clone()

The objects of this class are cloneable with this method.

Usage
geoflow_validator_cell$clone(deep = FALSE)
Arguments
deep

Whether to make a deep clone.


geoflow documentation built on Sept. 5, 2026, 5:08 p.m.