| geoflow_validator_entity_Date | R Documentation |
geoflow_validator_entity_Date
geoflow_validator_entity_Date
geoflow::geoflow_validator_cell -> geoflow_validator_entity_Date
geoflow::geoflow_validator_cell$getDefaultKey()geoflow::geoflow_validator_cell$getValidKeys()geoflow::geoflow_validator_cell$isErrorIfInvalidKey()geoflow::geoflow_validator_cell$isExcludeHttpKeys()geoflow::geoflow_validator_cell$isKeyRequired()geoflow::geoflow_validator_cell$isKeySynthaxUser()geoflow::geoflow_validator_cell$isMultiple()geoflow::geoflow_validator_cell$isNaAuthorized()new()Initializes an entity 'Date' cell
geoflow_validator_entity_Date$new(i, j, str)
irow index (internal index to be used for graphical geoflow validation handlers)
jcol index (internal index to be used for graphical geoflow validation handlers)
strstring to validate
validate()Validates a date. Proceeds with syntactic validation and content validation.
geoflow_validator_entity_Date$validate()
an validation report, as object of class data.frame
clone()The objects of this class are cloneable with this method.
geoflow_validator_entity_Date$clone(deep = FALSE)
deepWhether to make a deep clone.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.