geoflow_validator_entity_Format: geoflow_validator_entity_Format

geoflow_validator_entity_FormatR Documentation

geoflow_validator_entity_Format

Description

geoflow_validator_entity_Format

geoflow_validator_entity_Format

Super class

geoflow::geoflow_validator_cell -> geoflow_validator_entity_Format

Methods

Public methods

Inherited methods

Method new()

Initializes an entity 'Format' cell

Usage
geoflow_validator_entity_Format$new(i, j, str)
Arguments
i

row index (internal index to be used for graphical geoflow validation handlers)

j

col index (internal index to be used for graphical geoflow validation handlers)

str

string to validate


Method clone()

The objects of this class are cloneable with this method.

Usage
geoflow_validator_entity_Format$clone(deep = FALSE)
Arguments
deep

Whether to make a deep clone.


geoflow documentation built on Dec. 12, 2025, 5:08 p.m.