geoflow_validator_entity_Identifier: geoflow_validator_entity_Identifier

geoflow_validator_entity_IdentifierR Documentation

geoflow_validator_entity_Identifier

Description

geoflow_validator_entity_Identifier

Super class

geoflow_validator_cell -> geoflow_validator_entity_Identifier

Methods

Public methods

Inherited methods

geoflow_validator_entity_Identifier$new()

Initializes an entity 'Identifier' cell

Usage
geoflow_validator_entity_Identifier$new(i, j, str)
Arguments
i

row index (internal index to be used for graphical geoflow validation handlers)

j

col index (internal index to be used for graphical geoflow validation handlers)

str

string to validate


geoflow_validator_entity_Identifier$validate()

Validates an entity identifier. Proceeds with syntactic validation and content validation for DOIs and UUIDs.

Usage
geoflow_validator_entity_Identifier$validate()
Returns

an validation report, as object of class data.frame


geoflow_validator_entity_Identifier$clone()

The objects of this class are cloneable with this method.

Usage
geoflow_validator_entity_Identifier$clone(deep = FALSE)
Arguments
deep

Whether to make a deep clone.


geoflow documentation built on Sept. 5, 2026, 5:08 p.m.