geoflow_validator_entity_Rights: geoflow_validator_entity_Rights

geoflow_validator_entity_RightsR Documentation

geoflow_validator_entity_Rights

Description

geoflow_validator_entity_Rights

geoflow_validator_entity_Rights

Super class

geoflow::geoflow_validator_cell -> geoflow_validator_entity_Rights

Methods

Public methods

Inherited methods

Method new()

Initializes an entity 'Rights' cell

Usage
geoflow_validator_entity_Rights$new(i, j, str)
Arguments
i

row index (internal index to be used for graphical geoflow validation handlers)

j

col index (internal index to be used for graphical geoflow validation handlers)

str

string to validate


Method clone()

The objects of this class are cloneable with this method.

Usage
geoflow_validator_entity_Rights$clone(deep = FALSE)
Arguments
deep

Whether to make a deep clone.


geoflow documentation built on Dec. 12, 2025, 5:08 p.m.