| geoflow_validator_entity_Title | R Documentation |
geoflow_validator_entity_Title
geoflow_validator_cell -> geoflow_validator_entity_Title
geoflow_validator_cell$getDefaultKey()geoflow_validator_cell$getValidKeys()geoflow_validator_cell$isErrorIfInvalidKey()geoflow_validator_cell$isExcludeHttpKeys()geoflow_validator_cell$isKeyRequired()geoflow_validator_cell$isKeySynthaxUser()geoflow_validator_cell$isMultiple()geoflow_validator_cell$isNaAuthorized()geoflow_validator_cell$validate()geoflow_validator_entity_Title$new()Initializes an entity 'Title' cell
geoflow_validator_entity_Title$new(i, j, str)
irow index (internal index to be used for graphical geoflow validation handlers)
jcol index (internal index to be used for graphical geoflow validation handlers)
strstring to validate
geoflow_validator_entity_Title$clone()The objects of this class are cloneable with this method.
geoflow_validator_entity_Title$clone(deep = FALSE)
deepWhether to make a deep clone.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.