get_line_separator: get_line_separator

View source: R/geoflow_utils.R

get_line_separatorR Documentation

get_line_separator

Description

get_line_separator get the line separator used by geoflow when extracting cell components for tabular data content handling. Default is set to an underscore followed by a line break.

Usage

get_line_separator()

Author(s)

Emmanuel Blondel, emmanuel.blondel1@gmail.com


geoflow documentation built on Dec. 12, 2025, 5:08 p.m.