| initWorkflow | R Documentation |
initWorkflow allows to init a workflow
initWorkflow(file, dir, outdir, jobDirPath, handleMetadata, session)
file |
a JSON or YAML configuration file |
dir |
a directory used to execute the workflow. This is the working directory, ie where local resources (data, metadata), should be located. |
outdir |
a directory where the geoflow will write the job outputs. |
jobDirPath |
a directory set-up for the job. Default is |
handleMetadata |
Default is |
session |
a shiny session object (optional) to run geoflow in a shiny context |
Emmanuel Blondel, emmanuel.blondel1@gmail.com
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.