load_workflow_environment: load_workflow_environment

View source: R/geoflow_utils.R

load_workflow_environmentR Documentation

load_workflow_environment

Description

load_workflow_environment loads a workflow environment by evaluating variable expressions in the form ${{variable}}. If no variable expression pattern is identified in the string, the function will return the original string.

Usage

load_workflow_environment(config, session)

Arguments

config

object of class list

session

a shiny session object (optional) to run geoflow in a shiny context.

Author(s)

Emmanuel Blondel, emmanuel.blondel1@gmail.com


geoflow documentation built on Dec. 12, 2025, 5:08 p.m.