set_line_separator: set_line_separator

View source: R/geoflow_utils.R

set_line_separatorR Documentation

set_line_separator

Description

set_line_separator set the line separator to be used by geoflow when extracting cell components for tabular data content handling.

Usage

set_line_separator(x)

Arguments

x

a string as object of class character representing the line separator.

Author(s)

Emmanuel Blondel, emmanuel.blondel1@gmail.com


geoflow documentation built on Dec. 12, 2025, 5:08 p.m.