unload_workflow_environment: unload_workflow_environment

View source: R/geoflow_utils.R

unload_workflow_environmentR Documentation

unload_workflow_environment

Description

unload_workflow_environment unloads a workflow environment, in the case environment was provided by means of a dotenv file, and loaded using dotenv by geoflow. The function will recover the session environment variables values (useful in case an environment variable was overwriten for the workflow execution).

Usage

unload_workflow_environment(config)

Arguments

config

object of class list

Author(s)

Emmanuel Blondel, emmanuel.blondel1@gmail.com


geoflow documentation built on Dec. 12, 2025, 5:08 p.m.