View source: R/writeWorkflowJobDataResource.R
| writeWorkflowJobDataResource | R Documentation |
writeWorkflowJobDataResource allows to transform datasource into different formats
writeWorkflowJobDataResource(entity, config, obj,
useFeatures, resourcename, useUploadSource,
createIndexes, overwrite, append, chunk.size,
type)
entity |
a entity object as read by |
config |
a configuration object as read by |
obj |
a sf file |
useFeatures |
a boolean condition to define if features must be attach to obj file |
resourcename |
name of data input |
useUploadSource |
a boolean condition to define if resourcename is same as uploadSource information |
createIndexes |
a boolean condition for possibility to create indexes for each column |
overwrite |
a boolean condition for writing to DB. Default is |
append |
a boolean condition for appending to DB existing table. Default is |
chunk.size |
an object of class |
type |
format to convert into. Formats supported: shp, csv, gpkg, parquet, dbtable |
Alexandre Bennici, bennicialexandre@gmail.com
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.