View source: R/geoflow_utils.R
| check_packages | R Documentation |
check_packages checks availability of a list of R packages in R. This
function is essentially used internally by geoflow in assocation to geoflow_software and
geoflow_action that would need specific packages to be imported in R.
check_packages(pkgs)
pkgs |
a vector of package names |
Emmanuel Blondel, emmanuel.blondel1@gmail.com
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.