View source: R/geoflow_utils.R
| enrich_text_from_entity | R Documentation |
enrich_text_from_entity will attempt to enrich an entity text property
from other entity metadata, depending on text variables handled by a pattern in the form
- If the entity property is a text, only the name of the property name is required.
- If the entity property is a list, then 2 subcases can be distinguished:
If it is a named list (such as entity descriptions), the text variable will be compound by the entity property name and the element_property name, in the form
If it is a unnamed list (such as list of keywords, list of relations, etc), the text variable will handle four elements: property (entity property name to look at), a key value pair to use for search within the list, an element_property for which the value should be picked up to enrich the text. The variable willbe in the form
enrich_text_from_entity(str, entity)
str |
a text to be enriched |
entity |
an object of class |
Emmanuel Blondel, emmanuel.blondel1@gmail.com
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.