View source: R/executeWorkflow.R
| executeWorkflow | R Documentation |
executeWorkflow allows to execute a workflow
executeWorkflow(file, dir, outdir, queue,
on_initWorkflowJob, on_initWorkflow, on_closeWorkflow,
monitor, session)
file |
a JSON geoflow configuration file |
dir |
a directory used to execute the workflow. This is the working directory, ie where local resources (data, metadata), should be located. |
outdir |
a directory where the geoflow will write the job outputs. |
queue |
an ipc queue to use geoflow in geoflow-shiny |
on_initWorkflowJob |
a function to trigger once |
on_initWorkflow |
a function to trigger once |
on_closeWorkflow |
a function to trigger once |
monitor |
a monitor function to increase progress bar |
session |
a shiny session object (optional) to run geoflow in a shiny context |
the path of the job directory
Emmanuel Blondel, emmanuel.blondel1@gmail.com
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.