Learn R Programming

geoflow (version 1.2.0)

geoflowLogger: geoflowLogger

Description

geoflowLogger

geoflowLogger

Arguments

Value

Object of R6Class for modelling a simple logger

Format

R6Class object.

Public fields

verbose

verbose

debug

debug

Methods


Method separator()

Util to separate chunks of logs of different natures

Usage

geoflowLogger$separator(char)

Arguments

char

A character to be used, eg '='


Method INFO()

Prints an INFO logger message

Usage

geoflowLogger$INFO(txt, ...)

Arguments

txt

logger message

...

values to be passed into txt. See sprintf


Method WARN()

Prints an WARN logger message

Usage

geoflowLogger$WARN(txt, ...)

Arguments

txt

logger message

...

values to be passed into txt. See sprintf


Method ERROR()

Prints an ERROR logger message

Usage

geoflowLogger$ERROR(txt, ...)

Arguments

txt

logger message

...

values to be passed into txt. See sprintf


Method DEBUG()

Prints an DEBUG logger message

Usage

geoflowLogger$DEBUG(txt, ...)

Arguments

txt

logger message

...

values to be passed into txt. See sprintf


Method new()

Initializes an object of class geoflowLogger

Usage

geoflowLogger$new(verbose = TRUE, debug = FALSE)

Arguments

verbose

TRUE if the logger is enabled, FALSE otherwise. Default is TRUE

debug

TRUE if the debugger is enabled, FALSE otherwise. Default is FALSE


Method clone()

The objects of this class are cloneable with this method.

Usage

geoflowLogger$clone(deep = FALSE)

Arguments

deep

Whether to make a deep clone.