geoflowLogger
geoflowLogger
Object of R6Class for modelling a simple logger
R6Class object.
verboseverbose
debugdebug
separator()Util to separate chunks of logs of different natures
geoflowLogger$separator(char)charA character to be used, eg '='
INFO()Prints an INFO logger message
geoflowLogger$INFO(txt, ...)txtlogger message
...values to be passed into txt. See sprintf
WARN()Prints an WARN logger message
geoflowLogger$WARN(txt, ...)txtlogger message
...values to be passed into txt. See sprintf
ERROR()Prints an ERROR logger message
geoflowLogger$ERROR(txt, ...)txtlogger message
...values to be passed into txt. See sprintf
DEBUG()Prints an DEBUG logger message
geoflowLogger$DEBUG(txt, ...)txtlogger message
...values to be passed into txt. See sprintf
new()Initializes an object of class geoflowLogger
geoflowLogger$new(verbose = TRUE, debug = FALSE)verboseTRUE if the logger is enabled, FALSE otherwise. Default is TRUE
debugTRUE if the debugger is enabled, FALSE otherwise. Default is FALSE
clone()The objects of this class are cloneable with this method.
geoflowLogger$clone(deep = FALSE)deepWhether to make a deep clone.