geoflow_contact: Geoflow contact class

geoflow_contactR Documentation

Geoflow contact class

Description

This class models a contact to be executed by geoflow

Format

R6Class object.

Details

geoflow_contact

Value

Object of R6Class for modelling a contact

Public fields

id

contact identifier

firstName

contact first name

lastName

contact lastname

organizationName

contact organization

positionName

contact position

role

contact role

voice

contact phone number

facsimile

contact facsimile

email

contact email

websiteUrl

contact website URL

websiteName

contact website name

postalAddress

contact postal address

postalCode

contact postal code

city

contact city

country

contact country

identifiers

contact identifiers

Methods

Public methods


Method new()

Initializes a geoflow_contact object

Usage
geoflow_contact$new()

Method setShinyEditorMode()

Set mode for geoflow-shiny

Usage
geoflow_contact$setShinyEditorMode(mode = c("creation", "edition"))
Arguments
mode

mode


Method getShinyEditorMode()

Get mode for geoflow-shiny

Usage
geoflow_contact$getShinyEditorMode()
Returns

the shiny editor mode


Method getAllowedKeyValuesFor()

Retrieves keys allowed for a given tabular field name. eg. "Identifier"

Usage
geoflow_contact$getAllowedKeyValuesFor(field)
Arguments
field

field name

Returns

the list of valid keys for the field considered


Method setIdentifier()

Sets an identifier by means of key

Usage
geoflow_contact$setIdentifier(key = "id", id)
Arguments
key

an identifier key. Default is "id"

id

the identifier


Method setId()

Sets an "id" identifier

Usage
geoflow_contact$setId(id)
Arguments
id

the identifier


Method setFirstName()

Sets contact first name

Usage
geoflow_contact$setFirstName(firstName)
Arguments
firstName

contact first name


Method setLastName()

Sets contact last name

Usage
geoflow_contact$setLastName(lastName)
Arguments
lastName

contact last name


Method setOrganizationName()

Sets contact organization name

Usage
geoflow_contact$setOrganizationName(organizationName)
Arguments
organizationName

contact organization name


Method setPositionName()

Sets contact position name

Usage
geoflow_contact$setPositionName(positionName)
Arguments
positionName

contact position name


Method setRole()

Sets contact role

Usage
geoflow_contact$setRole(role)
Arguments
role

the contact role


Method setVoice()

Sets contact voice (phone number)

Usage
geoflow_contact$setVoice(voice)
Arguments
voice

contact voice (phone number)


Method setFacsimile()

Sets contact facsimile

Usage
geoflow_contact$setFacsimile(facsimile)
Arguments
facsimile

contact facsimile


Method setEmail()

Sets contact email

Usage
geoflow_contact$setEmail(email)
Arguments
email

contact email


Method setWebsiteUrl()

Sets contact website URL

Usage
geoflow_contact$setWebsiteUrl(websiteUrl)
Arguments
websiteUrl

contact website URL


Method setWebsiteName()

Sets contact website name

Usage
geoflow_contact$setWebsiteName(websiteName)
Arguments
websiteName

contact website name


Method setPostalAddress()

Sets the contact postal address

Usage
geoflow_contact$setPostalAddress(postalAddress)
Arguments
postalAddress

contact postal address


Method setPostalCode()

Sets the contact postal code

Usage
geoflow_contact$setPostalCode(postalCode)
Arguments
postalCode

contact postalCode


Method setCity()

Sets the contact city

Usage
geoflow_contact$setCity(city)
Arguments
city

contact city


Method setCountry()

Sets the contact country

Usage
geoflow_contact$setCountry(country)
Arguments
country

contact country


Method asDataFrame()

Methods to export the geoflow_contact as data.frame using key-based syntax.

Usage
geoflow_contact$asDataFrame(line_separator = NULL)
Arguments
line_separator

a line separator. By default, the default line separator will be used.

Returns

an object of class data.frame giving the entities using key-based syntax


Method clone()

The objects of this class are cloneable with this method.

Usage
geoflow_contact$clone(deep = FALSE)
Arguments
deep

Whether to make a deep clone.

Author(s)

Emmanuel Blondel <emmanuel.blondel1@gmail.com>

Examples

## Not run: 
  contact <- geoflow_contact$new()
  contact$setId("john.doe@nowhere.org")
  contact$setFirstName("John")
  contact$setLastName("Doe")
  contact$setOrganizationName("Nowhere")
  contact$setPositionName("Wizard")
  contact$setRole("Manager")
  contact$setVoice("+9999000000000")
  contact$setFacsimile("+9999000000001")
  contact$setEmail("john.doe@nowhere.org")
  contact$setWebsiteUrl("www.nowhere.org")
  contact$setWebsiteName("Nowhere Inc.")
  contact$setPostalAddress("Nowhere street")
  contact$setPostalCode("Nowhere code")
  contact$setCity("Nowhere city")
  contact$setCountry("Nowhere country")

## End(Not run)


geoflow documentation built on Dec. 12, 2025, 5:08 p.m.