| geoflow_data | R Documentation |
This class models a data object
R6Class object.
geoflow_data
Object of R6Class for modelling a data object
diran object of class character giving a data directory
datalist of object of class geoflow_data in case we point to a data directory
accessaccessor key for accessing sources. Default is 'default'
sourcesource
sourceFidsourceFid
sourceSqlsourceSql
sourceTypesource type
sourceZipcreate a zip for the sources (DEPRECATED with #344)
sourceZipOnlycreate a zip only for the sources, remove source files (DEPRECATED with #344)
sqlsql
uploadupload
uploadSourceupload source name
uploadTypeupload type
cqlfilterCQL filter for filtering data
workspacesworkspaces
storestore
layernamelayer name
layertitlelayer title
layerdesclayer description
layerurilayer URI layeruri layer URI
stylesstyles
styleUploadupload styles
dimensionsdimensions
cloud_patha relative path in a cloud storage (e.g., OCS)
spatialRepresentationTypespatial representation type eg. "vector", "grid"
ogc_dimensionsOGC dimensions
featuresfeatures
parametersparameters
geometryFieldgeometry field
geometryTypegeometry type
featureTypefeature type name
featureTypeObjfeature type object
attributesattributes
variablesvariables
coveragescoverages
envelopeCompositionTypeenvelope composition type (for coverages)
selectedResolutionselected resolution (for coverages)
selectedResolutionIndexselected resolution index (for coverages)
bandslist of bands
actionslocal actions
runwhether to run local actions
new()Initializes an object of class geoflow_data
geoflow_data$new(str = NULL, config = NULL)
strcharacter string to initialize from, using key-based syntax
configa geoflow config, if available and needed
getDir()Get data directory where datasets are scanned to build geoflow_data objects
geoflow_data$getDir()
an object of class character
getData()Get a lis tof geoflow_data objects built from a directory
geoflow_data$getData()
a list of objects of class geoflow_data
getAllowedSourceValues()Get allowed source values
geoflow_data$getAllowedSourceValues()
a vector of class character
setAccess()Set accessor id. See list_data_accessors() for available accessors
geoflow_data$setAccess(access)
accessa data data accessor id
getAllowedSourceTypes()Get allowed source types
geoflow_data$getAllowedSourceTypes()
a vector of class character
setSourceType()Set the source type.
The source type is a simplification of the data mime type and is used to identify the type of source
set for the data object. By default it is assumed to be "other" (undefined). The source types currently
allowed in geoflow can be listed with $getAllowedSourcedTypes().
geoflow_data$setSourceType(sourceType)
sourceTypesource type
getAllowedGeomPossibleNames()Get allowed Geometry possible names for coercing data to sf objects
geoflow_data$getAllowedGeomPossibleNames()
listof geom possible names
getAllowedXPossibleNames()Get allowed X possible names for coercing data to sf objects
geoflow_data$getAllowedXPossibleNames()
listof X possible names
getAllowedYPossibleNames()Get allowed Y possible names for coercing data to sf objects
geoflow_data$getAllowedYPossibleNames()
listof Y possible names
addSource()Add source, object of class "character" (single source)
geoflow_data$addSource(source)
sourcesource
setSource()Set source, object of class "character" (single source), or list.
For spatial source, a single source will be used, while for sources of type 'other'
(eg PDF files), multiple sources can be specified
geoflow_data$setSource(source)
sourcesource
setSourceFid()Set source FID, object of class "character" (single source FID), or list.
geoflow_data$setSourceFid(sourceFid)
sourceFidsourceFid
setSourceSql()This is a convenience method for users that want to specify directly
a SQL source. This method is called internally when a source SQL file has been set using
setSource
geoflow_data$setSourceSql(sourceSql)
sourceSqla source SQL query
setSourceZip()Sets whether a zipped version of the data file(s) should be created from source files. Default is FALSE
geoflow_data$setSourceZip(sourceZip)
sourceZipzip sources, object of class logical
setSourceZipOnly()Sets whether a zipped version of the data file(s) only should be created from source files. Default is FALSE
geoflow_data$setSourceZipOnly(sourceZipOnly)
sourceZipOnlyzip sources only, object of class logical
setUploadSource()Set the source to upload in output software, alternative to the source. If leave empty, the source will be used as uploadSource. A typical use case is when we want to get a CSV source to import in a database, and use the dbtable (or view/query) as upload source for publication in software like geoserver.
geoflow_data$setUploadSource(uploadSource)
uploadSourceupload source
getAllowedUploadTypes()Get allowed upload types
geoflow_data$getAllowedUploadTypes()
the list of allowed upload types
setUploadType()The upload type is a simplification of the data mime type and is used to identify the type of data uploaded.
By default it is assumed to be "other" (undefined). The upload types currently allowed in geoflow can be
listed with $getAllowedUploadTypes().
geoflow_data$setUploadType(uploadType)
uploadTypeupload type
setUpload()Set whether the source data should be uploaded to the sofware output declared in the geoflow
configuration or not. By default it is assumed that upload should be performed (upload TRUE).
geoflow_data$setUpload(upload)
uploadupload
setStyleUpload()Set whether styles in source data should be uploaded, by default TRUE
geoflow_data$setStyleUpload(styleUpload)
styleUploadstyle upload
setSql()Sets SQL for publication purpose.
geoflow_data$setSql(sql)
sqlsql
setCqlFilter()Sets a CQL filter. In case of spatial data, once the data is read by geoflow (during initialization phase), the CQL filter will be applied to the data.
geoflow_data$setCqlFilter(cqlfilter)
cqlfilterCQL filter
setWorkspace()Sets a workspace name, object of class character. A workspace must target a valid software type, object of
class character, to be declared as first argument of this function, assuming the corresponding software is
declared in the geoflow configuration.
geoflow_data$setWorkspace(software_type, workspace)
software_typesotware type where the workspace is identifier
workspaceworkspace name
setStore()Sets a data/coverage store name, object of class character. Used as target data/coverage store name for GeoServer action.
geoflow_data$setStore(store)
storestore
setDatastore()Sets a datastore name, object of class character. Used as target datastore name for GeoServer action. DEPRECATED, use setStore
geoflow_data$setDatastore(datastore)
datastoredatastore
setLayername()Sets a layername, object of class character. Used as target layer name for Geoserver action.
geoflow_data$setLayername(layername)
layernamelayername
setLayertitle()Sets a layer title, object of class character. If available, used as target layer title in SDI-related action.
geoflow_data$setLayertitle(layertitle)
layertitlelayertitle
setLayerdesc()Sets a layer description, object of class character. If available, used as target layer description/abstract in SDI-related actions.
geoflow_data$setLayerdesc(layerdesc)
layerdesclayerdesc
setLayeruri()Sets a layer URI, object of class character. If available, used as annotating URI for layer metadata (eg. in ISO 19115 action).
geoflow_data$setLayeruri(layeruri)
layerurilayeruri
addStyle()Adds a style name, object of class character. Used as layer style name(s) for GeoServer action.
geoflow_data$addStyle(style)
stylestyle
addDimension()Adds a dimension
geoflow_data$addDimension(name, dimension)
namedimension name
dimensionobject of class geoflow_dimension
setCloudPath()Set cloud path
geoflow_data$setCloudPath(cloud_path)
cloud_pathcloud path
getAllowedSpatialRepresentationTypes()Get allowed spatial representation types, typically "vector" and "grid"
geoflow_data$getAllowedSpatialRepresentationTypes()
an object of class character
setSpatialRepresentationType()Set spatial representation type for the data considered
geoflow_data$setSpatialRepresentationType(spatialRepresentationType)
spatialRepresentationTypespatial representation type
setOgcDimensions()Set OGC dimensions
geoflow_data$setOgcDimensions(name, values)
namedimension name
valuesdimension values
setFeatures()Set data features
geoflow_data$setFeatures(features)
featuresfeatures
setParameter()Set virtual parameter definition for setting virtual SQL view parametized layers in Geoserver, when uploadType is
set to dbquery.The arguments here follow the definition of virtual parameters in GeoServer, ie a name (alias),
the corresponding field name in the DBMS, a regular expression for validation of parameter values (required to
prevent SQL injection risks), and a default value.
geoflow_data$setParameter(name, fieldname, regexp, defaultvalue)
namename
fieldnamefieldname
regexpregexp
defaultvaluedefault value
setGeometryField()Sets the name of the geometry field in the target GeoServer SQL view parametrized layer
geoflow_data$setGeometryField(geometryField)
geometryFieldgeometry field
setGeometryType()Sets the name of the geometry field in the target GeoServer SQL view parametrized layer
geoflow_data$setGeometryType(geometryType)
geometryTypegeometry type
setFeatureType()Sets a feature type (ID) to link data with a dictionnary
geoflow_data$setFeatureType(featureType)
featureTypefeature type name
setFeatureTypeObj()Sets a feature type object
geoflow_data$setFeatureTypeObj(featureTypeObj)
featureTypeObjfeature type object of class geoflow_featuretype
setAttributes()Set attributes, as simple way to describe attributes without binding to a proper geoflow_dictionary.
geoflow_data$setAttributes(attributes)
attributesattributes
setVariables()Set variables, as simple way to describe variables without binding to a proper geoflow_dictionary.
geoflow_data$setVariables(variables)
variablesvariables
setCoverages()Set coverages
geoflow_data$setCoverages(coverages)
coveragescoverages
getAllowedEnvelopeCompositionTypes()Get allowed envelope composition types
geoflow_data$getAllowedEnvelopeCompositionTypes()
an object of class character
setEnvelopeCompositionType()Set envelope composition type
geoflow_data$setEnvelopeCompositionType(envelopeCompositionType)
envelopeCompositionTypeenvelope composition type, either 'UNION' or 'INTERSECTION'
setSelectedResolution()Set selected resolution
geoflow_data$setSelectedResolution(selectedResolution)
selectedResolutionselected resolution
setSelectedResolutionIndex()Set selected resolution index
geoflow_data$setSelectedResolutionIndex(selectedResolutionIndex)
selectedResolutionIndexselected resolution index
setBand()Set band
geoflow_data$setBand(name, index)
nameband name
indexband index
addAction()Adds a local action
geoflow_data$addAction(action)
actionobject of class geoflow_action
checkSoftwareProperties()A function triggered when loading a data object to check eventual software dependent properties, to make sure the corresponding software are declared in the config.
geoflow_data$checkSoftwareProperties(config)
configgeoflow config object
clone()The objects of this class are cloneable with this method.
geoflow_data$clone(deep = FALSE)
deepWhether to make a deep clone.
Emmanuel Blondel <emmanuel.blondel1@gmail.com>
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.