| geoflow_data_accessor | R Documentation |
This class models a data accessor to be used by geoflow
R6Class object.
geoflow_data_accessor
Object of R6Class for modelling a data accessor
geoflow::geoflowLogger -> geoflow_data_accessor
idaccessor ID
software_typeaccessor software type
definitionaccessor definition
packageslist of packages required for the accessor
downloada download function handler
lista function handler to list resources in case of a data directory
new()Initializes the data ccessor
geoflow_data_accessor$new( id = NULL, software_type = NULL, definition, packages = list(), download, list = NULL )
idaccessor ID
software_typeaccessor software type
definitionaccessor definition
packageslist of packages required for the accessor
downloaddownload function handler
listlist function handler
setId()Sets accessor ID
geoflow_data_accessor$setId(id)
idaccessor ID to set
setSoftwareType()Sets software type
geoflow_data_accessor$setSoftwareType(software_type)
software_typesoftware type
setPackages()Sets list of packages required for the accessor
geoflow_data_accessor$setPackages(packages)
packagesa vecto of package names
setDefinition()Sets accessor definition
geoflow_data_accessor$setDefinition(definition)
definitionaccessor definition
setDownload()Set download handler (a function with arguments resource,
file, path, unzip (TRUE/FALSE) and optional software)
geoflow_data_accessor$setDownload(download)
downloadan object of class function
setList()Set list handler (a function with no arguments)
geoflow_data_accessor$setList(list)
listan object of class function
checkPackages()Check that all packages required for the software are available, if yes,
import them in the R session, and return a data.frame giving the
packages names and version. If one or more packages are unavailable,
an error is thrown and user informed of the missing packages.
geoflow_data_accessor$checkPackages()
clone()The objects of this class are cloneable with this method.
geoflow_data_accessor$clone(deep = FALSE)
deepWhether to make a deep clone.
Emmanuel Blondel <emmanuel.blondel1@gmail.com>
## Not run:
access <- geoflow_data_accessor$new(
id = "some-id",
software_type = "some-software",
definition = "definition",
packages = list(),
download = function(resource, file, path, software, unzip){},
list = function(resource, software){}
)
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.