| geoflow_dictionary | R Documentation |
This class models a dictionary to be executed by geoflow
R6Class object.
geoflow_dictionary
Object of R6Class for modelling a dictionary
sourcedictionary source, object of class data.frame
featuretypeslist of objects of class geoflow_featuretype
registerslist of objects of class geoflow_register
new()Initializes a geoflow_dictionary object
geoflow_dictionary$new()
setSource()Sets dictionnary source
geoflow_dictionary$setSource(source)
sourceobject of class data.frame
getFeatureTypes()Get the list of geoflow_featuretype defined in the dictionary
geoflow_dictionary$getFeatureTypes()
a list of geoflow_featuretype
getFeatureTypeById()Get an object of class geoflow_featuretype given an ID
geoflow_dictionary$getFeatureTypeById(id)
idid
an object of class geoflow_featuretype, otherwise NULL
addFeatureType()Adds a feature type to the dictionnary
geoflow_dictionary$addFeatureType(ft)
ftobject of class geoflow_featuretype
getRegisters()Get the list of registers associated with the dictionnary
geoflow_dictionary$getRegisters()
a list of geoflow_register objects
getRegisterById()Get register by ID
geoflow_dictionary$getRegisterById(id)
idid
an object of class geoflow_register, otherwise NULL
addRegister()Adds a register to the dictionnary
geoflow_dictionary$addRegister(register)
registerobject of class geoflow_register
clone()The objects of this class are cloneable with this method.
geoflow_dictionary$clone(deep = FALSE)
deepWhether to make a deep clone.
Emmanuel Blondel <emmanuel.blondel1@gmail.com>
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.