| geoflow_register | R Documentation |
This class models a register to be used by geoflow
R6Class object.
geoflow_register
Object of R6Class for modelling a register
idregister id
defregister def
funregister function
dataregister data
new()Initializes an object of class geoflow_register
geoflow_register$new(id, def, fun)
idid
defdef
funfun
fetch()Fetchs the register data using the register function
geoflow_register$fetch(config = NULL)
configa geoflow config object
check()Checks the register data structure. The structure of the data.frame returned
by the register function should be of 4 columns including "code", "uri", "label", "definition".
In case the data structure is not valid, the function throws an error.
geoflow_register$check(data)
dataa register data structure
clone()The objects of this class are cloneable with this method.
geoflow_register$clone(deep = FALSE)
deepWhether to make a deep clone.
Emmanuel Blondel <emmanuel.blondel1@gmail.com>
## Not run:
register <- geoflow_register$new(
id = "some-id",
def = "definition",
fun = function(){}
)
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.