| geoflow_software | R Documentation |
This class models a software to be used by geoflow
R6Class object.
geoflow_software
Object of R6Class for modelling a software
geoflow::geoflowLogger -> geoflow_software
idsoftware id
typesoftware I/O type ("input" or "output")
software_typetype of software
definitiondefinition
packageslist of packages required for the software functioning
handlersoftware handler function
argumentssoftware arguments
parameterssoftware parameters
attributessoftware attributes
propertiessoftware properties
actionsactions associated with the software
new()Initializes a software
geoflow_software$new( id = NULL, type = NULL, software_type, packages = list(), definition, handler, arguments, attributes = list(), actions = list() )
idid
typetype "input" or "output"
software_typesoftware type
packageslist of packages required for the software functioning
definitionsoftware definition
handlersoftware handler function
argumentssoftware handler arguments
attributessoftware attributes
actionssoftware actions
setId()Sets software ID
geoflow_software$setId(id)
idid
setType()Set type. Either "input" or "output"
geoflow_software$setType(type)
typesoftware I/O type
setSoftwareType()Set software type
geoflow_software$setSoftwareType(software_type)
software_typesoftware type
setPackages()Set software required packages
geoflow_software$setPackages(packages)
packageslist of package names
setDefinition()Set software definition
geoflow_software$setDefinition(definition)
definitionsoftware definition
setAttributes()Set attributes. Function to call when creating an instance of geoflow_software
geoflow_software$setAttributes(attributes)
attributesnamed list of attributes
setProperties()Set properties. Function to call to pass argument values for a given geoflow_software
geoflow_software$setProperties(props)
propsnamed list of properties
setArguments()Set software arguments. Function to call when creating an instance of geoflow_software
geoflow_software$setArguments(arguments)
argumentslist of software arguments
setParameters()Set parameters. Function to call to pass argument values for a given geoflow_software
geoflow_software$setParameters(params)
paramsnamed list of parameters
setActions()Set software actions
geoflow_software$setActions(actions)
actionsa list of geoflow_action
setHandler()Set the software handler function
geoflow_software$setHandler(handler)
handlerobject of class function
checkPackages()Check that all packages required for the software are available, if yes,
import them in the R session, and return a data.frame giving the
packages names and version. If one or more packages are unavailable,
an error is thrown and user informed of the missing packages.
geoflow_software$checkPackages()
getHandlerInstance()Get the software handler instance
geoflow_software$getHandlerInstance()
an object instance of the software handler
clone()The objects of this class are cloneable with this method.
geoflow_software$clone(deep = FALSE)
deepWhether to make a deep clone.
Emmanuel Blondel <emmanuel.blondel1@gmail.com>
## Not run:
software<- geoflow_software$new(
id = "some-id",
type = "output",
software_type = "software",
definition = "definition",
packages = list(),
handler = function(){},
arguments = list(
url = list(def = "the software url")
),
attributes = list(
workspace = list(def = "a workspace name in the software")
)
)
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.