| geoflow_validator | R Documentation |
geoflow_validator
geoflow_validator
sourceobject of class data.frame handling metadata objects to validate
new()Initializes a table validator for a given metadata model
geoflow_validator$new(model, valid_columns, source)
modelthe data model name, eg. "entity", "contact"
valid_columnsa vector of valid columns for the data model
sourcean object of class data.frame handling the contacts
validate_structure()Validates a source table against a data model structure
geoflow_validator$validate_structure()
TRUE if valid, FALSE otherwise.
validate_content()Validates a source table using syntactic and content validation rules
geoflow_validator$validate_content(raw = FALSE)
rawindicates whether to return a list of geoflow_validator_cell objects or a data.frame
debugdebug validation
a list of geoflow_validator_cell objects, or data.frame
clone()The objects of this class are cloneable with this method.
geoflow_validator$clone(deep = FALSE)
deepWhether to make a deep clone.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.