| geoflow_validator_cell | R Documentation |
geoflow_validator_cell
geoflow_validator_cell
irow index (internal index to be used for graphical geoflow validation handlers)
jcol index (internal index to be used for graphical geoflow validation handlers)
new()Initializes a geoflow_validator_cell
geoflow_validator_cell$new( na_authorized, use_key_syntax, key_required, valid_keys, default_key, error_if_invalid_key, exclude_http_keys, multiple, i, j, str )
na_authorizedif validator cell authorizes NAs or empty strings. Default is FALSE
use_key_syntaxif validator cell uses key-based syntax. Default is TRUE
key_requiredif validator cell has a key required. Default is TRUE
valid_keysvalid keys for the validator cell. Default is an empty list
default_keydefault_key to use if key is omitted. Default is NULL
error_if_invalid_keyraise an error if key is invalid. Default is TRUE
exclude_http_keysif 'http' keys have to be excluded from validation checks. Default is TRUE
multipleif cell may contain multiple values. Deprecated
irow index (internal index to be used for graphical geoflow validation handlers)
jcol index (internal index to be used for graphical geoflow validation handlers)
strcharacter string to validate
isNaAuthorized()Indicates if the validator cell authorizes NAs and empty strings
geoflow_validator_cell$isNaAuthorized()
TRUE if authorizes NAs and empty strings, FALSE otherwise
isKeySynthaxUser()Indicates if the validator cell makes use of key-based syntax
geoflow_validator_cell$isKeySynthaxUser()
TRUE if using key-based syntax, FALSE otherwise
isKeyRequired()Indicates if a key is required for the validator cell
geoflow_validator_cell$isKeyRequired()
TRUE if requires a key, FALSE otherwise
getValidKeys()Gives the list of valid keys for the validator cell
geoflow_validator_cell$getValidKeys()
the list of valid keys
isErrorIfInvalidKey()Indicates if a report error will be given in case of invalid key
geoflow_validator_cell$isErrorIfInvalidKey()
TRUE if a report error will be given in case of invalid key, FALSE otherwise
getDefaultKey()Gets the default key
geoflow_validator_cell$getDefaultKey()
the default key
isExcludeHttpKeys()Indicates if 'http' keys are excluded from the validation
geoflow_validator_cell$isExcludeHttpKeys()
TRUE if 'http' keys are excluded from the validation, FALSE otherwise
isMultiple()indicates if multiple key-based components can be used within a same cell
geoflow_validator_cell$isMultiple()
TRUE if supporting multiple key-based components by cell, FALSE otherwise
validate()Proceeds with syntactic validation for the cell considered
geoflow_validator_cell$validate()
an object of class data.frame including possible errors/warnings
clone()The objects of this class are cloneable with this method.
geoflow_validator_cell$clone(deep = FALSE)
deepWhether to make a deep clone.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.