| geoflow_validator_entity_Rights | R Documentation |
geoflow_validator_entity_Rights
geoflow_validator_entity_Rights
geoflow::geoflow_validator_cell -> geoflow_validator_entity_Rights
geoflow::geoflow_validator_cell$getDefaultKey()geoflow::geoflow_validator_cell$getValidKeys()geoflow::geoflow_validator_cell$isErrorIfInvalidKey()geoflow::geoflow_validator_cell$isExcludeHttpKeys()geoflow::geoflow_validator_cell$isKeyRequired()geoflow::geoflow_validator_cell$isKeySynthaxUser()geoflow::geoflow_validator_cell$isMultiple()geoflow::geoflow_validator_cell$isNaAuthorized()geoflow::geoflow_validator_cell$validate()new()Initializes an entity 'Rights' cell
geoflow_validator_entity_Rights$new(i, j, str)
irow index (internal index to be used for graphical geoflow validation handlers)
jcol index (internal index to be used for graphical geoflow validation handlers)
strstring to validate
clone()The objects of this class are cloneable with this method.
geoflow_validator_entity_Rights$clone(deep = FALSE)
deepWhether to make a deep clone.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.