initWorkflow: initWorkflow

View source: R/initWorkflow.R

initWorkflowR Documentation

initWorkflow

Description

initWorkflow allows to init a workflow

Usage

initWorkflow(file, dir, jobDirPath, handleMetadata, session)

Arguments

file

a JSON or YAML configuration file

dir

a directory where to execute the workflow.

jobDirPath

a directory set-up for the job. Default is NULL means it will be created during initialization of the workflow, otherwise the path provided will be used.

handleMetadata

Default is TRUE. Metadata contacts/entities/dictionary will be handled. If set to FALSE, they will not be handled. This is used for example in geoflow Shiny app where we want to initialize config without handling metadata to inherit software connections and test dynamically the metadata validity.

session

a shiny session object (optional) to run geoflow in a shiny context

Author(s)

Emmanuel Blondel, emmanuel.blondel1@gmail.com


geoflow documentation built on Dec. 12, 2025, 5:08 p.m.