View source: R/geoflow_utils.R
| load_workflow_environment | R Documentation |
load_workflow_environment loads a workflow environment by evaluating variable expressions in the
form ${{variable}}. If no variable expression pattern is identified in the string,
the function will return the original string.
load_workflow_environment(config, session)
config |
object of class list |
session |
a shiny session object (optional) to run geoflow in a shiny context. |
Emmanuel Blondel, emmanuel.blondel1@gmail.com
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.