View source: R/geoflow_utils.R
| unload_workflow_environment | R Documentation |
unload_workflow_environment unloads a workflow environment, in the case environment
was provided by means of a dotenv file, and loaded using dotenv by geoflow. The function will
recover the session environment variables values (useful in case an environment variable was overwriten for
the workflow execution).
unload_workflow_environment(config)
config |
object of class list |
Emmanuel Blondel, emmanuel.blondel1@gmail.com
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.